require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xexchaccepteddomain',
  dscmeta_resource_friendly_name: 'xExchAcceptedDomain',
  dscmeta_resource_name: 'MSFT_xExchAcceptedDomain',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xExchange',
  dscmeta_module_version: '1.33.0',
  docs: 'The DSC xExchAcceptedDomain resource type.
         Automatically generated from version 1.33.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_makedefault: {
      type: 'Optional[Boolean]',
      desc: 'The MakeDefault parameter specifies whether the accepted domain is the default domain.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'Optional[String]',
      desc: 'The Name parameter specifies a unique name for the accepted domain object.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_matchsubdomains: {
      type: 'Optional[Boolean]',
      desc: 'The MatchSubDomains parameter enables mail to be sent by and received from users on any subdomain of this accepted domain.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_domaintype: {
      type: "Optional[Enum['Authoritative', 'ExternalRelay', 'InternalRelay']]",
      desc: 'The DomainType parameter specifies the type of accepted domain that you want to configure.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domainname: {
      type: 'String',
      desc: 'The domain name of the accepted domain.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials used to establish a remote PowerShell session to Exchange.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies whether this accepted domain should be present or absent',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_addressbookenabled: {
      type: 'Optional[Boolean]',
      desc: 'The AddressBookEnabled parameter specifies whether to enable recipient filtering for this accepted domain.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
