require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xexchimapsettings',
  dscmeta_resource_friendly_name: 'xExchImapSettings',
  dscmeta_resource_name: 'MSFT_xExchImapSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xExchange',
  dscmeta_module_version: '1.33.0',
  docs: 'The DSC xExchImapSettings resource type.
         Automatically generated from version 1.33.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_maxconnections: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The MaxConnections parameter specifies the maximum number of IMAP4 connections that are accepted by the Exchange server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_banner: {
      type: 'Optional[String]',
      desc: "The Banner parameter specifies the text string that's displayed to connecting IMAP4 clients.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logintype: {
      type: "Optional[Enum['PlainTextLogin', 'PlainTextAuthentication', 'SecureLogin']]",
      desc: 'The LoginType parameter specifies the authentication method for IMAP4 connections.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enforcecertificateerrors: {
      type: 'Optional[Boolean]',
      desc: 'The EnforceCertificateErrors parameter specifies whether to enforce valid Secure Sockets Layer (SSL) certificate validation failures.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableexactrfc822size: {
      type: 'Optional[Boolean]',
      desc: 'The EnableExactRFC822Size parameter specifies how message sizes are presented to IMAP4 clients.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_showhiddenfoldersenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ShowHiddenFoldersEnabled parameter specifies whether hidden mailbox folders are visible.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_preauthenticatedconnectiontimeout: {
      type: 'Optional[String]',
      desc: "The PreAuthenticatedConnectionTimeout parameter specifies the period of time to wait before closing an idle IMAP4 connection that isn't authenticated.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_owaserverurl: {
      type: 'Optional[String]',
      desc: "The OwaServerUrl parameter specifies the URL that's used to retrieve calendar information for instances of custom Outlook on the web calendar items.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_externalconnectionsettings: {
      type: 'Optional[Array[String]]',
      desc: "The ExternalConnectionSettings parameter specifies the host name, port, and encryption method that's used by external IMAP4 clients (IMAP4 connections from outside your corporate network).",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_extendedprotectionpolicy: {
      type: "Optional[Enum['None', 'Allow', 'Require']]",
      desc: 'The ExtendedProtectionPolicy parameter specifies how Extended Protection for Authentication is used.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_authenticatedconnectiontimeout: {
      type: 'Optional[String]',
      desc: 'The AuthenticatedConnectionTimeout parameter specifies the period of time to wait before closing an idle authenticated connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logfilelocation: {
      type: 'Optional[String]',
      desc: 'The LogFileLocation parameter specifies the location for the IMAP4 protocol log files.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxconnectionsperuser: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The MaxConnectionsPerUser parameter specifies the maximum number of IMAP4 connections that are allowed for each user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_calendaritemretrievaloption: {
      type: "Optional[Enum['iCalendar', 'IntranetUrl', 'InternetUrl', 'Custom']]",
      desc: 'The CalendarItemRetrievalOption parameter specifies how calendar items are presented to IMAP4 clients.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logperfilesizequota: {
      type: 'Optional[String]',
      desc: 'The LogPerFileSizeQuota parameter specifies the maximum size of a IMAP4 protocol log file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logfilerolloversettings: {
      type: "Optional[Enum['Hourly', 'Daily', 'Weekly', 'Monthly']]",
      desc: 'The LogFileRollOverSettings parameter specifies how frequently IMAP4 protocol logging creates a new log file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowservicerestart: {
      type: 'Optional[Boolean]',
      desc: 'Whether it is OK to restart the IMAP services after making changes. Defaults to $false.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxcommandsize: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The MaxCommandSize parameter specifies the maximum size in bytes of a single IMAP4 command.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_protocollogenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ProtocolLogEnabled parameter specifies whether to enable protocol logging for IMAP4.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_unencryptedortlsbindings: {
      type: 'Optional[Array[String]]',
      desc: "The X509CertificateName parameter specifies the certificate that's used for encrypting IMAP4 client connections.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials used to establish a remote PowerShell session to Exchange.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_domaincontroller: {
      type: 'Optional[String]',
      desc: "The DomainController parameter specifies the domain controller that's used by this cmdlet to read data from or write data to Active Directory. You identify the domain controller by its fully qualified domain name (FQDN). For example, dc01.contoso.com.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_suppressreadreceipt: {
      type: 'Optional[Boolean]',
      desc: 'The SuppressReadReceipt parameter specifies whether to stop duplicate read receipts from being sent to IMAP4 clients that have the Send read receipts for messages I send setting configured in their IMAP4 email program.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxconnectionfromsingleip: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The MaxConnectionFromSingleIP parameter specifies the maximum number of IMAP4 connections that are accepted by the Exchange server from a single IP address.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_x509certificatename: {
      type: 'Optional[String]',
      desc: "The X509CertificateName parameter specifies the certificate that's used for encrypting IMAP4 client connections.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sslbindings: {
      type: 'Optional[Array[String]]',
      desc: "The SSLBindings parameter specifies the IP address and TCP port that's used for IMAP4 connection that's always encrypted by SSL/TLS. This parameter uses the syntax <IPv4OrIPv6Address>:<Port>.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_internalconnectionsettings: {
      type: 'Optional[Array[String]]',
      desc: "The InternalConnectionSettings parameter specifies the host name, port, and encryption method that's used by internal IMAP4 clients (IMAP4 connections from inside your corporate network).",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enablegssapiandntlmauth: {
      type: 'Optional[Boolean]',
      desc: 'The EnableGSSAPIAndNTLMAuth parameter specifies whether connections can use Integrated Windows authentication (NTLM) using the Generic Security Services application programming interface (GSSAPI). This setting applies to connections where Transport Layer Security (TLS) is disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_server: {
      type: 'String',
      desc: 'The IMAP server to configure.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxytargetport: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The ProxyTargetPort parameter specifies the port on the Microsoft Exchange IMAP4 Backend service that listens for client connections that are proxied from the Microsoft Exchange IMAP4 service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_messageretrievalmimeformat: {
      type: "Optional[Enum['TextOnly', 'HtmlOnly', 'HtmlAndTextAlternative', 'TextEnrichedOnly', 'TextEnrichedAndTextAlternative', 'BestBodyFormat', 'Tnef']]",
      desc: 'The MessageRetrievalMimeFormat parameter specifies the MIME encoding of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
