require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xexchmailboxtransportservice',
  dscmeta_resource_friendly_name: 'xExchMailboxTransportService',
  dscmeta_resource_name: 'MSFT_xExchMailboxTransportService',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xExchange',
  dscmeta_module_version: '1.33.0',
  docs: 'The DSC xExchMailboxTransportService resource type.
         Automatically generated from version 1.33.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_mailboxdeliverythrottlinglogenabled: {
      type: 'Optional[Boolean]',
      desc: 'The MailboxDeliveryThrottlingLogEnabled parameter specifies whether the mailbox delivery throttling log is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_receiveprotocollogmaxdirectorysize: {
      type: 'Optional[String]',
      desc: 'The ReceiveProtocolLogMaxDirectorySize parameter specifies the maximum size of the protocol log directory for the implicit and invisible mailbox delivery Receive connector in the Mailbox Transport Delivery service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_routingtablelogmaxage: {
      type: 'Optional[String]',
      desc: 'The RoutingTableLogMaxAge parameter specifies the maximum routing table log age.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxsubmissionagentlogmaxdirectorysize: {
      type: 'Optional[String]',
      desc: 'The MailboxSubmissionAgentLogMaxDirectorySize parameter specifies the maximum size of all Mailbox Transport Submission service agent logs in the agent log directory.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_identity: {
      type: 'String',
      desc: 'Exchange server',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sendprotocollogpath: {
      type: 'Optional[String]',
      desc: 'The SendProtocolLogPath parameter specifies the location of the protocol log directory for the implicit and invisible intra-organization Send connector in the Mailbox Transport Submission service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxdeliveryconnectormaxinboundconnection: {
      type: 'Optional[String]',
      desc: 'The MailboxDeliveryConnectorMaxInboundConnection parameter specifies the maximum number of inbound connections for the implicit and invisible mailbox delivery Receive connector in the Mailbox Transport Delivery service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_routingtablelogmaxdirectorysize: {
      type: 'Optional[String]',
      desc: 'The RoutingTableLogMaxDirectorySize parameter specifies the maximum size of the routing table log directory.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_pipelinetracingenabled: {
      type: 'Optional[Boolean]',
      desc: 'The PipelineTracingEnabled parameter specifies whether to enable pipeline tracing.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_mailboxdeliveryagentlogpath: {
      type: 'Optional[String]',
      desc: 'The MailboxDeliveryAgentLogPath parameter specifies the default agent log directory location for the Mailbox Transport Delivery service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_routingtablelogpath: {
      type: 'Optional[String]',
      desc: 'The RoutingTableLogPath parameter specifies the directory location where routing table log files should be stored.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_mailboxdeliverythrottlinglogmaxage: {
      type: 'Optional[String]',
      desc: 'The MailboxDeliveryThrottlingLogMaxAge parameter specifies the maximum age for the mailbox delivery throttling log file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_connectivitylogenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ConnectivityLogEnabled parameter specifies whether the connectivity log is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials used to establish a remote PowerShell session to Exchange',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_allowservicerestart: {
      type: 'Optional[Boolean]',
      desc: 'Whether it is OK to restart service MSExchangeTransport',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_receiveprotocollogmaxage: {
      type: 'Optional[String]',
      desc: 'The ReceiveProtocolLogMaxAge parameter specifies the maximum age of a protocol log file for the implicit and invisible mailbox delivery Receive connector in the Mailbox Transport Delivery service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sendprotocollogmaxdirectorysize: {
      type: 'Optional[String]',
      desc: 'The SendProtocolLogMaxDirectorySize parameter specifies the maximum size of the protocol log directory for the implicit and invisible intra-organization Send connector in the Mailbox Transport Submission service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxsubmissionagentlogmaxfilesize: {
      type: 'Optional[String]',
      desc: 'The MailboxSubmissionAgentLogMaxFileSize parameter specifies the maximum size of each agent log file for the Mailbox Transport Submission service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxconcurrentmailboxsubmissions: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The MaxConcurrentMailboxSubmissions parameter specifies the maximum number of submission threads that the transport service can have open at the same time to send messages from mailboxes.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_sendprotocollogmaxage: {
      type: 'Optional[String]',
      desc: 'The SendProtocolLogMaxAge parameter specifies the maximum age of a protocol log file for the implicit and invisible intra-organization Send connector in the Mailbox Transport Submission service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_pipelinetracingsenderaddress: {
      type: 'Optional[String]',
      desc: 'The PipelineTracingSenderAddress parameter specifies the sender email address that invokes pipeline tracing.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxdeliveryagentlogmaxdirectorysize: {
      type: 'Optional[String]',
      desc: 'The MailboxDeliveryAgentLogMaxDirectorySize parameter specifies the maximum size of all Mailbox Transport Delivery service agent logs in the agent log directory.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_connectivitylogmaxage: {
      type: 'Optional[String]',
      desc: 'The ConnectivityLogMaxAge parameter specifies the maximum age for the connectivity log file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domaincontroller: {
      type: 'Optional[String]',
      desc: "The DomainController parameter specifies the domain controller that's used by this cmdlet to read data from or write data to Active Directory.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxdeliveryconnectorsmtputf8enabled: {
      type: 'Optional[Boolean]',
      desc: 'The MailboxDeliveryConnectorSmtpUtf8Enabled parameters or disables email address internationalization (EAI) support for the implicit and invisible mailbox delivery Receive connector in the Mailbox Transport Delivery service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_mailboxsubmissionagentlogenabled: {
      type: 'Optional[Boolean]',
      desc: 'The MailboxSubmissionAgentLogEnabled parameter specifies whether the agent log is enabled for the Mailbox Transport Submission service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_receiveprotocollogpath: {
      type: 'Optional[String]',
      desc: 'The ReceiveProtocolLogPath parameter specifies the location of the protocol log directory for the implicit and invisible mailbox delivery Receive connector in the Mailbox Transport Delivery service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxdeliverythrottlinglogpath: {
      type: 'Optional[String]',
      desc: 'The MailboxDeliveryThrottlingLogPath parameter specifies the default mailbox delivery throttling log directory location.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sendprotocollogmaxfilesize: {
      type: 'Optional[String]',
      desc: 'The SendProtocolLogMaxFileSize parameter specifies the maximum size of a protocol log file for the implicit and invisible intra-organization Send connector in the Mailbox Transport Submission service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxdeliverythrottlinglogmaxdirectorysize: {
      type: 'Optional[String]',
      desc: 'The MailboxDeliveryThrottlingLogMaxDirectorySize parameter specifies the maximum size of all mailbox delivery throttling logs in the mailbox delivery throttling log directory.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_connectivitylogmaxdirectorysize: {
      type: 'Optional[String]',
      desc: 'The ConnectivityLogMaxDirectorySize parameter specifies the maximum size of all connectivity logs in the connectivity log directory.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxdeliveryconnectorprotocollogginglevel: {
      type: 'Optional[String]',
      desc: 'The MailboxDeliveryConnectorProtocolLoggingLevel parameter enables or disables SMTP protocol logging for the implicit and invisible mailbox delivery Receive connector in the Mailbox Transport Delivery service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxsubmissionagentlogpath: {
      type: 'Optional[String]',
      desc: 'The MailboxSubmissionAgentLogPath parameter specifies the default agent log directory location for the Mailbox Transport Submission service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_connectivitylogpath: {
      type: 'Optional[String]',
      desc: 'The ConnectivityLogPath parameter specifies the default connectivity log directory location.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_receiveprotocollogmaxfilesize: {
      type: 'Optional[String]',
      desc: 'The ReceiveProtocolLogMaxFileSize parameter specifies the maximum size of a protocol log file for the implicit and invisible mailbox delivery Receive connector in the Mailbox Transport Delivery service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxdeliveryagentlogmaxfilesize: {
      type: 'Optional[String]',
      desc: 'The MailboxDeliveryAgentLogMaxFileSize parameter specifies the maximum size of each agent log file for the Mailbox Transport Delivery service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_connectivitylogmaxfilesize: {
      type: 'Optional[String]',
      desc: 'The ConnectivityLogMaxFileSize parameter specifies the maximum size of each connectivity log file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxdeliveryagentlogenabled: {
      type: 'Optional[Boolean]',
      desc: 'The MailboxDeliveryAgentLogEnabled parameter specifies whether the agent log for the Mailbox Transport Delivery service is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_mailboxdeliverythrottlinglogmaxfilesize: {
      type: 'Optional[String]',
      desc: 'The MailboxDeliveryThrottlingLogMaxFileSize parameter specifies the maximum size of each mailbox delivery throttling log file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_pipelinetracingpath: {
      type: 'Optional[String]',
      desc: 'The PipelineTracingPath parameter specifies the location of the pipeline tracing logs.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxsubmissionagentlogmaxage: {
      type: 'Optional[String]',
      desc: 'The MailboxSubmissionAgentLogMaxAge parameter specifies the maximum age for the agent log file of the Mailbox Transport Submission service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_contentconversiontracingenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ContentConversionTracingEnabled parameter specifies whether content conversion tracing is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_mailboxdeliveryagentlogmaxage: {
      type: 'Optional[String]',
      desc: 'The MailboxDeliveryAgentLogMaxAge parameter specifies the maximum age for the agent log file of the Mailbox Transport Delivery service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxconcurrentmailboxdeliveries: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The MaxConcurrentMailboxDeliveries parameter specifies the maximum number of delivery threads that the transport service can have open at the same time to deliver messages to mailboxes.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
  },
)
