require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xexchreceiveconnector',
  dscmeta_resource_friendly_name: 'xExchReceiveConnector',
  dscmeta_resource_name: 'MSFT_xExchReceiveConnector',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xExchange',
  dscmeta_module_version: '1.33.0',
  docs: 'The DSC xExchReceiveConnector resource type.
         Automatically generated from version 1.33.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_maxacknowledgementdelay: {
      type: 'Optional[String]',
      desc: "Specifies the period the transport server delays acknowledgement when receiving messages from a host that doesn't support shadow redundancy.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxlocalhopcount: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum number of local hops that a message can take before the message is rejected by the Receive connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_requireehlodomain: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the client must provide a domain name in the EHLO handshake after the SMTP connection is established.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_deliverystatusnotificationenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DSN (delivery status notification) Extended SMTP extension is enabled or disabled on the Receive connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_remoteipranges: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the remote IP addresses that the Receive connector accepts messages from.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_fqdn: {
      type: 'Optional[String]',
      desc: "Specifies the destination FQDN that's shown to connected messaging servers.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_extendedrightallowentries: {
      type: 'Optional[Array[Struct[{
              key => Optional[String],
              value => Optional[String],
            }]]]',
      desc: 'Additional allow permissions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_KeyValuePair[]',
      mof_is_embedded: true,
    },
    dsc_banner: {
      type: 'Optional[String]',
      desc: "Specifies a custom SMTP 220 banner that's displayed to remote messaging servers.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_servicediscoveryfqdn: {
      type: 'Optional[String]',
      desc: 'Specifies the service discovery fully-qualified domain name (FQDN)',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to enable or disable the Receive connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_bindings: {
      type: 'Optional[Array[String]]',
      desc: "Specifies the local IP address and TCP port number that's used by the Receive connector.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_barelinefeedrejectionenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether this Receive connector rejects messages that contain line feed (LF) characters without immediately preceding carriage return characters (CR) in the SMTP DATA stream.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tlsdomaincapabilities: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the capabilities that the Receive connector makes available to specific hosts outside of the organization.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_tlscertificatename: {
      type: 'Optional[String]',
      desc: 'Specifies the X.509 certificate to use for TLS encryption.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_identity: {
      type: 'String',
      desc: 'Identity of the Receive Connector. Needs to be in format SERVERNAME\\CONNECTORNAME (no quotes).',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxinboundconnectionpercentagepersource: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum number of connections that this Receive connector serves at the same time from a single IP address.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_requiretls: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to require TLS transmission for inbound messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_advertiseclientsettings: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the SMTP server name, port number, and authentication settings for the Receive connector are displayed to users in the options of Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_extendedprotectionpolicy: {
      type: "Optional[Enum['None', 'Allow', 'Require']]",
      desc: 'Specifies how you want to use Extended Protection for Authentication on the Receive connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_chunkingenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the CHUNKING Extended SMTP extension is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableauthgssapi: {
      type: 'Optional[Boolean]',
      desc: 'enables or disables Kerberos when Integrated Windows authentication is available on the Receive connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_transportrole: {
      type: "Optional[Enum['FrontendTransport', 'HubTransport']]",
      desc: 'Specifies the transport service on the Mailbox server where the Receive connector is created.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxmessagesize: {
      type: 'Optional[String]',
      desc: "Specifies the maximum size of a message that's allowed through the Receive connector.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxinboundconnectionpersource: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum number of connections that a Receive connector serves at the same time from a single IP address, expressed as the percentage of available remaining connections on a Receive connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_defaultdomain: {
      type: 'Optional[String]',
      desc: 'Specifies the default accepted domain to use for the Exchange organization.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials used to establish a remote PowerShell session to Exchange.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_comment: {
      type: 'Optional[String]',
      desc: 'Specifies an optional comment.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_binarymimeenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the BINARYMIME Extended SMTP extension is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_protocollogginglevel: {
      type: "Optional[Enum['None', 'Verbose']]",
      desc: 'pecifies whether to enable or disable protocol logging.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_permissiongroups: {
      type: "Optional[Array[Enum['None', 'AnonymousUsers', 'ExchangeUsers', 'ExchangeServers', 'ExchangeLegacyServers', 'Partners', 'Custom']]]",
      desc: 'Specifies the well-known security principals who are authorized to use the Receive connector and the permissions that are assigned to them.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_orarenabled: {
      type: 'Optional[Boolean]',
      desc: 'enables or disables Originator Requested Alternate Recipient (ORAR) on the Receive connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_domainsecureenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to enable or disable mutual Transport Layer Security (TLS) authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_authtarpitinterval: {
      type: 'Optional[String]',
      desc: 'Specifies the period of time to delay responses to failed authentication attempts from remote servers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxhopcount: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum number of hops that a message can take before the message is rejected by the Receive connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Enum['Present', 'Absent']",
      desc: 'Whether the connector should be present or not.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usage: {
      type: "Optional[Enum['Client', 'Internal', 'Internet', 'Partner', 'Custom']]",
      desc: 'Specifies the default permission groups and authentication methods that are assigned to the Receive connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domaincontroller: {
      type: 'Optional[String]',
      desc: "Specifies the domain controller that's used by this cmdlet to read data from or write data to Active Directory.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxheadersize: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum size of the SMTP message header before the Receive connector closes the connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_eightbitmimeenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the 8BITMIME Extended SMTP extension is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_connectiontimeout: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum time that the connection to the Receive connector can remain open, even if the connection is actively transmitting data.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxlogonfailures: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'pecifies the number of logon failures that the Receive connector retries before it closes the connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_messageratesource: {
      type: "Optional[Enum['None', 'IPAddress', 'User', 'All']]",
      desc: 'Specifies how the message submission rate is calculated.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_longaddressesenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the Receive connector accepts long X.400 email addresses.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxprotocolerrors: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum number of SMTP protocol errors that the Receive connector accepts before closing the connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_tarpitinterval: {
      type: 'Optional[String]',
      desc: 'Specifies the period of time to delay an SMTP response to a remote server that may be abusing the connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_suppressxanonymoustls: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the X-ANONYMOUSTLS Extended SMTP extension is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_messageratelimit: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum number of messages that can be sent by a single client IP address per minute.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_authmechanism: {
      type: "Optional[Array[Enum['None', 'Tls', 'Integrated', 'BasicAuth', 'BasicAuthRequireTLS', 'ExchangeServer', 'ExternalAuthoritative']]]",
      desc: 'Specifies the advertised and accepted authentication mechanisms for the Receive connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_pipeliningenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the PIPELINING Extended SMTP extension is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxrecipientspermessage: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum number of recipients per message that the Receive connector accepts before closing the connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_extendedrightdenyentries: {
      type: 'Optional[Array[Struct[{
              key => Optional[String],
              value => Optional[String],
            }]]]',
      desc: 'Additional denz permissions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_KeyValuePair[]',
      mof_is_embedded: true,
    },
    dsc_maxinboundconnection: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum number of inbound connections that this Receive connector serves at the same time.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_connectioninactivitytimeout: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum amount of idle time before a connection to the Receive connector is closed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enhancedstatuscodesenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the ENHANCEDSTATUSCODES Extended SMTP extension is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sizeenabled: {
      type: "Optional[Enum['Enabled', 'Disabled', 'EnabledWithoutValue']]",
      desc: 'Specifies how the SIZE Extended SMTP extension is used on the Receive connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
