require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xexchsendconnector',
  dscmeta_resource_friendly_name: 'xExchSendConnector',
  dscmeta_resource_name: 'MSFT_xExchSendConnector',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xExchange',
  dscmeta_module_version: '1.33.0',
  docs: 'The DSC xExchSendConnector resource type.
         Automatically generated from version 1.33.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_forcehelo: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether HELO is sent instead of the default EHLO.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ignorestarttls: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to ignore the StartTLS option offered by a remote sending server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_fqdn: {
      type: 'Optional[String]',
      desc: 'Specifies the FQDN used as the source server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_extendedrightallowentries: {
      type: 'Optional[Array[Struct[{
              key => Optional[String],
              value => Optional[String],
            }]]]',
      desc: 'Additional allow permissions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_KeyValuePair[]',
      mof_is_embedded: true,
    },
    dsc_isscopedconnector: {
      type: 'Optional[Boolean]',
      desc: 'Specifies the availability of the connector to other Mailbox servers with the Transport service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to enable the Send connector to process email messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tlscertificatename: {
      type: 'Optional[String]',
      desc: 'Specifies the X.509 certificate to use for TLS encryption.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_smarthosts: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the smart hosts the Send connector uses to route mail.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_useexternaldnsserversenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the connector uses the external DNS list specified by the ExternalDNSServers parameter of the Set-TransportService cmdlet.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxmessagesize: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum size of a message that can pass through a connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_addressspaces: {
      type: 'Array[String]',
      desc: 'Specifies the domain names to which the Send connector routes mail.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials used to establish a remote PowerShell session to Exchange.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_comment: {
      type: 'Optional[String]',
      desc: 'Specifies an optional comment.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_requiretls: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether all messages sent through this connector must be transmitted using TLS.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_port: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the port number for smart host forwarding.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_domainsecureenabled: {
      type: 'Optional[Boolean]',
      desc: 'Enables mutual Transport Layer Security (TLS) authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sourceipaddress: {
      type: 'Optional[String]',
      desc: 'Specifies the local IP address to use as the endpoint for an SMTP connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_frontendproxyenabled: {
      type: 'Optional[Boolean]',
      desc: 'Routes outbound messages through the CAS server,where destination specific routing, such as DNS or IP address, is set.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Whether the connector should be present or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_errorpolicies: {
      type: "Optional[Enum['Default', 'DowngradeAuthFailures', 'DowngradeDNSFailures']]",
      desc: 'Specifies how communication errors are treated.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usage: {
      type: "Optional[Enum['Internal', 'Internet', 'Partner', 'Custom']]",
      desc: 'Specifies the default permissions and authentication methods assigned to the Send connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domaincontroller: {
      type: 'Optional[String]',
      desc: "Specifies the domain controller that's used by this cmdlet to read data from or write data to Active Directory.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_authenticationcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: "Specifies the username and password that's required to use the connector.",
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_connectortype: {
      type: "Optional[Enum['Default', 'XPremises']]",
      desc: 'Specifies whether the connector is used in hybrid deployments to send messages to Office 365.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sourcetransportservers: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the names of the Mailbox servers that can use this Send connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_linkedreceiveconnector: {
      type: 'Optional[String]',
      desc: 'Specifies whether to force all messages received by the specified Receive connector out through this Send connector.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_smarthostauthmechanism: {
      type: "Optional[Enum['None', 'BasicAuth', 'BasicAuthRequireTLS', 'ExchangeServer', 'ExternalAuthoritative']]",
      desc: 'Specifies the smart host authentication mechanism to use for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_iscoexistenceconnector: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether this Send connector is used for secure mail flow between your on-premises deployment and your Microsoft Office 365 organization.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tlsdomain: {
      type: 'Optional[String]',
      desc: 'Specifies the domain name that the Send connector uses to verify the FQDN of the target certificate.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dnsroutingenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the Send connector uses Domain Name System (DNS) to route mail.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tlsauthlevel: {
      type: "Optional[Enum['EncryptionOnly', 'CertificateValidation', 'DomainValidation']]",
      desc: 'Specifies the TLS authentication level that is used for outbound TLS connections.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_extendedrightdenyentries: {
      type: 'Optional[Array[Struct[{
              key => Optional[String],
              value => Optional[String],
            }]]]',
      desc: 'Additional deny permissions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_KeyValuePair[]',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'Specifies a descriptive name for the connector.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_smtpmaxmessagesperconnection: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum number of messages the server can send per connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_connectioninactivitytimeout: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum time an idle connection can remain open.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_protocollogginglevel: {
      type: "Optional[Enum['None', 'Verbose']]",
      desc: 'Specifies whether to enable protocol logging.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
