require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xexchwaitforadprep',
  dscmeta_resource_friendly_name: 'xExchWaitForADPrep',
  dscmeta_resource_name: 'MSFT_xExchWaitForADPrep',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xExchange',
  dscmeta_module_version: '1.33.0',
  docs: 'The DSC xExchWaitForADPrep resource type.
         Automatically generated from version 1.33.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_retrycount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many retry attempts should be made to see if AD has been prepped before an exception is thrown. Defaults to 30.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_domainversion: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies that the domain containing the target Exchange 2013 server was prepared using setup /PrepareAD, /PrepareDomain, or /PrepareAllDomains, and should be at the specified version',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_exchangedomains: {
      type: 'Optional[Array[String]]',
      desc: "The FQDN's of domains that should be checked for DomainVersion in addition to the domain that this Exchange server belongs to",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_identity: {
      type: 'String',
      desc: "Not actually used. Enter anything, as long as it's not null",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials used to perform Active Directory lookups against the Schema, Configuration, and Domain naming contexts',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_retryintervalsec: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many seconds to wait between retries when checking whether AD has been prepped. Defaults to 60.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_organizationversion: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: "Specifies that the Exchange Organization should have been prepared using Exchange 2013 'setup /PrepareAD', and should be at the specified version",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_schemaversion: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: "Specifies that the Active Directory schema should have been prepared using Exchange 2013 'setup /PrepareSchema', and should be at the specified version",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
  },
)
